==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaDoplacajacaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class InstytucjaDoplacajacaKontoBankoweKey extends GenericDPSObject {
    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kontoId;

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKontoId() {
        return kontoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaDoplacajacaKontoBankoweKey other = (InstytucjaDoplacajacaKontoBankoweKey) that;
        return (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kontoId=").append(kontoId);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InstytucjaDoplacajacaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class InstytucjaDoplacajacaKontoBankoweKey extends GenericDPSObject {
    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kontoId;

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKontoId() {
        return kontoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * INSTYTUCJA_DOPLACAJACA_KONTO_BANKOWE.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InstytucjaDoplacajacaKontoBankoweKey other = (InstytucjaDoplacajacaKontoBankoweKey) that;
        return (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kontoId=").append(kontoId);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append("]");
        return sb.toString();
    }
}
